* migstat06_stata.zip: migstat06.do 
* =============================================================================

* Stata/MP 12.1 for Windows

clear
capture log close
set more off
* set memory 800m
set dp comma
set linesize 250

* Arbeitsverzeichnis in '<...>' eintragen; z. B. c:\temp */ 
cd '<Arbeitsverzeichnis>'

log using migstat2006.log, replace text

/* ============================================================================

STATA-PROGRAMM ZUR TYPISIERUNG DES MIGRATIONSSTATUS IM MIKROZENSUS 2006

Programmautor/en:
   SAS-Originalprogramm: Gunter Brueckner (Statistisches Bundesamt;
            Referat F 204 Migration und integration, Wohnen)
   Anpassungen an Scientific Use File Mikrozensus 2006: Delia Jaeger
            Bernhard Schimpl-Neimanns (GESIS, GML)
          
Programmzweck:
   Dieses Programm dient der Replikation des Migrationsstatus, Variable MIG, 
   und der Staatsangehoerigkeit zum Migrationsstatus (MIGS) im Scientific Use
   File (SUF) des Mikrozensus 2006.
   Die Programme basieren auf den SAS-Programmen zum Original-Mikrozensus des 
   Statistischen Bundesamtes und wurden an Recodierungen des SUF angepasst.
   Bei der Replikation der Variablen Staatsangehoerigkeit zum Migrationsstatus 
   (MIGS) ist zu beachten, dass aus Gruenden des Datenschutzes Angaben zur 
   zweiten Staatsangehoerigkeit (EF370) nur rudimentaer vorhanden sind.
   Des Weiteren sind die zur Konstruktion von MIGS verwendeten Variablen 
       EF369 1. Staatsangehoerigkeit
   und EF374 Staatsangehoerigkeit: vor Einbuergerung
   unterschiedlich codiert. Die Replikation ist deshalb nur eingeschraenkt 
   moeglich.

Weiterfuehrende Programmbeschreibung:
   Jaeger, Delia und Bernhard Schimpl-Neimanns: Typisierung des 
   Migrationshintergrundes in den Mikrozensus Scientific-Use-Files 2005-2009.
   GESIS-Technical Report Nr. 2012/08. Mannheim: GESIS. URL:
      http://www.gesis.org/fileadmin/upload/forschung/publikationen/
      gesis_reihen/gesis_methodenberichte/2012/TechnicalReport_2012-08.pdf

Download dieser Datei:
   http://www.gesis.org/missy/studie/klassifikationen/
   konzepte-und-definitionen/migrationshintergrund/migstat06_stata.zip
   Siehe auch Anhang 1: Personen mit Migrationshintergrund - Auf dem Weg zu 
   einer definitorischen Abgrenzung - S. 398-407 in: Statistisches Bundesamt,
   2011: Bevoelkerung mit Migrationshintergrund. Ergebnisse des Mikrozensus 
   2009. Fachserie 1 Reihe 2.2. Wiesbaden. URL: 
   https://www.destatis.de/DE/Publikationen/Thematisch/Bevoelkerung/
   MigrationIntegration/Migrationshintergrund2010220097004.pdf?__blob=
   publicationFile; letzter Zugriff: 24.07.2012

Programmstruktur:
   0. Datenvorbereitung: ID_2007.do
   1. Grundtypisierung des Migationshintergrundes
   2. Identifikation von 3-Generationen-Haushalten
   3. Endtypisierung der Grosseltern
   4. Endtypisierung der Eltern
   5. Endtypisierung Befragte
   6. Umsetzung von Zeitreihenkompatibilitaet (entfaellt im MZ 2006)
   7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse

Programmstatus:
  Getestet mit Stata/MP 12.1 for Windows und dem Scientific Use File 
  Mikrozensus 2006, Version 1 vom 19.02.2009
  Stand: Juli 2012.
============================================================================ */


* Variablenauswahl SUF MZ 2006 einlesen 
*    Vollstaendigen Dateinamen inkl. Verzeichnis in < > eintragen
use EF1 EF3 EF4 EF5a EF5b EF8 EF9 EF12 EF30 EF31 EF44 EF46 EF47 ///
    EF49 EF50 EF51 EF52 EF53 EF54 EF55 EF366 EF367 EF368 EF369  ///
    EF370 EF371 EF372 EF373 EF374 EF570 EF663 EF732 EF952 ///
 using <mz2006.dta> clear


* ====================================================================
* 0. DATENVORBEREITUNG 

* Korrektur doppelter Identifikatoren, siehe:
* http://www.gesis.org/missy/fileadmin/missy/daten/mikrodaten_tools/
*    Rekodierung_doppelter_Identifikatoren/ID_2006.do
do ID_2006.do

* Gross- => Kleinschreibung der Variablennamen
renpfix EF ef
* Variablenlabel mit Code versehen
numlabel _all, add mask("[#] ")

/* Neue HHNR bilden, um Extraprogramme fuer Jahresbestand (EF5b=0)
   und Jahresueberhang (EF5b=1) zu vermeiden; EF12 Berichtsquartal

ZU BEACHTEN:
Im Scientific Use File des Mikrozensus 2006 sind die Identifikatoren (ID) fuer 
Haushalte des Jahresueberhangs (EF5b=1) teilweise inkonsistent, sodass die in 
den Daten vorhandenen IDs zur Abgrenzung von  Haushalten (EF3, EF4, EF5b, EF12)
nicht immer eindeutig sind. Die im Folgenden verwendeten Rekodierungen der 
Haushaltsnummer (EF4, ex: EF4R) und der Personennummer (v5=EF5a, ex: EF5aR) 
reduzieren die Abweichungen zwischen der selbst ermittelten Haushaltsgroesse 
im Vergleich zur abgeleiteten Variablen EF663 von ueber 2.200 
Faellen vor der Plausibilisierung auf 637 Faelle. 
Allerdings wuerde dieser Vorteil durch die Sortierfolge 
   EF1, EF3, V4 [EF4R | EF5b | EF12], EF5aR 
wieder aufgehoben. Im Folgenden wird deshalb die Haushaltsabgrenzung mit 
dieser Sortierfolge
   EF1, EF3, EF4R, EF5aR
vorgenommen. 
*/

rename ef4   EF4_ORG
rename ef5a  EF5a_ORG
rename ef4R  ef4
rename ef5aR ef5a 

gen v4=ef4
label var v4 "HHNR EF4 ohne ef5b und ef12"

* Neue Personennummer
gen v5=ef5a
label var v5 "Personennr. im HH korrigiert (EF5aR)"

* Neue Sortierfolge
sort ef1 ef3 v4 v5

order ef1 ef3 ef4 v4 ef5a v5 ef5b ef12 ef8-ef952


/* Harmonisierung der Staatsangehoerigkeiten
---------------------------------------------------------------------------
ZU BEACHTEN: Aufgrund unterschiedlicher Codierungen bei der Anonymisierung
des Scientific Use Files bei den Variablen EF369 und EF374 sowie im Vergleich
zu den Originaldaten kann die Staatsangehoerigkeit zum Migrationsstatus 
(SA_erw, MIGS) nicht bzw. nur naeherungsweise repliziert werden.

EF369 1. Staatsangehoerigkeit   | EF374 Staatsangehoerigk.: vor Einbuerg.
   1 = 01,07,11,15,17-19,31,37  |    1 = 1,18
   3 = 03,25                    |
   4 = 04,08,27                 |    4 = 04,08,11,27
                                |    7 = 07,15
                                |   10 = 10,37
  12 = 12,16,20,28,39           |   12 = 12,16,20,28,39
                                |   24 = 24,32
  30 = 30,33                    |
  43 = 43,44                    |   43 = 43,44
  45 = 45,46                    |
  52 = 52,54                    |
  55 = 55,98                    |   55 = 55,98
--------------------------------------------------------------------------- */

* Originalvariablen sichern
rename ef369 EF369_ORG
rename ef374 EF374_ORG

* Harmonisierte Recodierung
recode EF369_ORG (32=24), gen(ef369) copyrest
recode EF374_ORG (4 10 19 7 17 31=1) (25=3) (33=30) (46=45) (54=52), ///
   gen(ef374) copyrest
label var ef369 "F98a 1. Staatsangehrigkeit (EF369_ORG recodiert)"
label var ef374 "F100b Staatsangehrigk.: vor Einbrgerung (EF374_ORG recodiert)"
format ef369 ef374 %2.0f
/* label def migs ///
    0 "Entfllt (Deutsche ohne weitere Staatsangehrigkeit)" /// 
    1 "EU-25: Belgien(01), Luxemburg(18), Irland(11), Zypern(37), Malta(19); Sonst. Europa: Estland(07), Lettland(15), Litauen(17), Slowenien(31)" /// 
    2 "Sonst. Europa: Bosnien und Herzegowina(02)" /// 
    3 "Sonst. Europa: Bulgarien(03), Rumnien(25)" /// 
    4 "EU-25: Dnemark(04), Finnland(08), Schweden(27)" /// 
    5 "Sonst. Europa: Ehemalige Sowjetunion(05)" /// 
    6 "Sonst. Europa: Ehemaliges Jugoslawien(06)" /// 
    9 "EU-25: Frankreich(09)" /// 
   10 "EU-25: Griechenland(10)" /// 
   12 "Sonst. Europa: Island(12), Liechtenstein(16), Norwegen(20), Schweiz(28), Sonstiges Europa(39)" /// 
   13 "EU-25: Italien(13)" /// 
   14 "Sonst. Europa: Kroatien(14)" /// 
   21 "EU-25: Niederlande(21)" /// 
   22 "EU-25: sterreich(22)" /// 
   23 "Sonst. Europa: Polen(23)" /// 
   24 "EU-25: Portugal(24), Spanien(32)" /// 
   26 "Sonst. Europa: Russische Fderation(26)" /// 
   29 "Sonst. Europa: Serbien und Montenegro(29)" /// 
   30 "Sonst. Europa: Slowakei(30), Tschechische Republik(33)" /// 
   34 "Sonst. Europa: Trkei(34)" /// 
   35 "Sonst. Europa: Ungarn(35)" /// 
   36 "EU-25: Vereinigtes Knigreich(36)" /// 
   38 "Sonst. Europa: Sonstiges Osteuropa(38)" /// 
   40 "Afrika: Marokko(40)" /// 
   41 "Afrika: Sonstiges Nordafrika(41)" /// 
   42 "Afrika: Sonstiges Afrika(42)" /// 
   43 "Amerika: Vereinigte Staaten(43), Sonstiges Nordamerika(43)" /// 
   45 "Amerika: Mittelamerika und Karibik(45), Sdamerika(46)" /// 
   47 "Naher und Mittlerer Osten: Irak(47)" /// 
   48 "Naher und Mittlerer Osten: Iran(48)" /// 
   49 "Sonstiger Naher und Mittlerer Osten(49)" /// 
   50 "Sd- und Sdostasien: Vietnam(50)" ///
   51 "Sd- und Sdostasien: Afghanistan(51)" ///
   52 "Sonstiges Sd- und Sdostasien(52), Sonstiges Ostasien(54)" ///
   53 "Ostasien: China(53)" ///
   55 "brige Welt(55), Staatenlos(98)" ///
   56 "Sonst. Europa: Ukraine(56)" ///
   57 "Naher und Mittlerer Osten: Kasachstan(57)" ///
   99 "Ohne Angabe"
label val ef369 migs
label val ef374 migs */

/* Weil Variable EF370 2. Staatsangehorrigkeit im SUF nur die Information 
    0 Entfaellt (Deutsche, Auslaender mit nur einer Staatsangeh.
und 1 vorhanden 
enthaelt, wird unten bei 
    * SA*: Staatsangehoerigkeit
    * nur deutsche SA
    (...) .
    * nur auslaendische SAs
       gen ausl=1.
       (...) 
die Zuweisung: 
    replace sa2=ef370 if ef368==8 & ef370!=0 
mit Kommentaren versehen und ist somit nicht mehr aktiv.
Andernfalls wuerde die Zuweisung des Codes 1 in den nachfolgenden 
Typisierungen faelschlicherweise als Staatsangehoerigkeit = Belgien (1)
interpretiert. */

* Zwischenspeicherung der Arbeitsdatei mit korrigierten IDs
save mz2006r_auswahl.dta, replace


/* ======================================================================
1. Grundtypisierung des Migrationshintergrundes

   Es werden zunaechst nur die Angaben der Person selbst zur Typisierung 
   verwendet. Die erste Typisierung erfolgt nach Angaben zur 
   Staatsangehoerigkeit (deutsch / nicht-deutsch) und Geburtsland 
   (Ausland / Inland).
*/

generate gebj=ef47
label var gebj "Geburtsjahr"

generate brdborn = ef366
label var brdborn "Geburtsland: BRD (ef366)"
label def brdborn 1 "[1] Ja, hier geboren" 8 "[8] Nein, zugezogen", add modify
label val brdborn brdborn

recode brdborn (1=0) (8=1) (9=9) (*=9), gen(zuzug)
label var zuzug "Zuzug ex BRDBorn, ef366"
label def zuzug 0 "[0] kein Zuzug" 1 "[1] foreign born" 2 "[2] Zuzug nach 6+ Mo im Ausland:= in D geboren", add modify
label val zuzug zuzug

recode ef367 (1949=1949) (9999=9) (0=0), gen(jzuzug) copyrest
label def jzuzug 1949 "Zuzug vor 1950" 9 "[9] o.A. zum Zuzugsjahr"  0 "[0] kein Zuzugsjahr sinnvoll", add modify
label val jzuzug jzuzug

replace zuzug=2  if brdborn==1 & jzuzug>9
replace jzuzug=9 if brdborn==8 & jzuzug<10


* Initialisierung
gen mig=.     // Migrationsstatus
gen ausl=.    // Auslaender
gen sadopp=.  // Doppelte Staatsangehoerigkeit
gen sa=.      // Aktuelle Staatsangehoerigkeit
gen sa1=.     // Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370
gen sa2=.     // Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370)
gen sa3=.     // Staatsangehoerigkeit vor Einbuergerung 
gen eingeb=.  // Eingebuergert
gen jeinb=.   // Jahr der Einbuergerung
gen sa_erw=.  // Erweiterte aktuelle Staatsangehoerigkeit

* nur deutsche Staatsangehoerigkeit (SA)
replace ausl=0   if ef368==1
replace sadopp=0 if ef368==1
replace sa1=0    if ef368==1
replace sa2=.    if ef368==1
  
* deutsche und auslaendische SA
replace ausl=0    if ef368==2
replace sadopp=1  if ef368==2 
replace sa1=0     if ef368==2
replace sa2=ef369 if ef368==2

* nur auslaendische SAs
replace ausl=1    if ef368==8
replace sa1=ef369 if ef368==8
replace sadopp=0  if ef368==8 & ef370==0 // ef370=0: Ausl. mit nur einer Staatsangeh.
replace sa2=.     if ef368==8 & ef370==0
replace sadopp=1  if ef368==8 & ef370!=0
/* auskommentiert, da in EF370 nur Code 1='vorhanden': replace sa2=ef370 if ef368==8 & ef370!=0  */

label def ausl    0 "[0] nein" 1 "[1] ja"
label def sadopp  0 "[0] nein" 1 "[1] ja"
label val ausl ausl 

* Einbuergerung
replace eingeb=1    if ef372==1 
replace jeinb=ef373 if ef372==1
replace jeinb=9     if ef372==1 & ef373==0
replace sa3=ef374   if ef372==1
replace sa3=.       if ef372==1 & ef374==0

* Keine Einbuergerung
replace eingeb=0 if ef372!=1
replace jeinb=9  if ef372!=1
replace sa3=0    if ef372!=1


/* ####### Grundtypisierung des Migrationshintergrundes ####### */
/* MIG: Migrationstypus
        1. Stelle: Migrationstyp: 
           1=vertrieben
           2=als Deutsche/r bzw. Spaetaussiedler zugewandert
           3=eingebuergert
           4=Auslaender/in
        2. Stelle: Generation:
           1=im Ausland geboren
           2=in Deutschland geboren

   MIG:   11=Vertriebene vor 1950
          21=Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung);
          22=Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung);
          25=(Spaet-)Aussiedler (mit Einbuergerung);
          29=(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr;
          31=zugewanderte/r eingebuergerte/r Auslaender/in;
          32=nicht zugewanderte/r eingebuergerte/r Auslaender/in;
          41=zugewanderte/r Auslaender/in;
          42=nicht zugewanderte/r Auslaender/in;
          77=uneindeutig ob deutsch, vertrieben oder Spaetaussiedler 
          99=fehlende/unvollstaendige Angaben 
   SA: aktuelle Staatsangehoerigkeit

   SA_erw: erweiterte aktuelle Staatsangehoerigkeit
             gewonnen aus SA1 - SA3 nach folgenden Regeln:
           0=deutsch (bei MIG=0, 11);
           =SA1 (bei Mig=41,42);
           =SA3 (bei Mig=21,25,29,31,32 und SA3<>.);
           =SA2 (bei MIG=21,25,29,31,32 und SA3=.und SA2<>.)
           =99 (bei MIG=21,25,29,31,32 und SA2=. und SA3=. oder bei MIG=77,99) */

* A) im Ausland geboren 
* A1) als Auslaender zugewandert
replace mig=41     if brdborn==8 & ausl==1
replace sa=sa1     if brdborn==8 & ausl==1 & mig==41
replace sa_erw=sa1 if brdborn==8 & ausl==1 & mig==41

* A2) Eingebuergerter
replace mig=31     if brdborn==8 & ausl==0 & eingeb==1 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==1 & mig==31
replace sa_erw=sa3 if brdborn==8 & ausl==0 & eingeb==1 & mig==31
replace sa_erw=sa2 if brdborn==8 & ausl==0 & eingeb==1 & mig==31 & sa_erw==.
replace sa_erw=99  if brdborn==8 & ausl==0 & eingeb==1 & mig==31 & sa_erw==.

* A3) Vertriebener vor 1950 
replace mig=11     if brdborn==8 & ausl==0 & eingeb==0 & jzuzug==1949 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==0 & jzuzug==1949 & mig==11
replace sa_erw=sa1 if brdborn==8 & ausl==0 & eingeb==0 & jzuzug==1949 & mig==11

* A4) als Deutscher zugewandert 
replace mig=21     if brdborn==8 & ausl==0 & eingeb==0 & jzuzug>1949 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==0 & jzuzug>1949 & mig==21
replace sa_erw=sa1 if brdborn==8 & ausl==0 & eingeb==0 & jzuzug>1949 & mig==21
replace sa_erw=sa2 if brdborn==8 & ausl==0 & eingeb==0 & jzuzug>1949 & mig==21 & sa2!=.

* ... Zuzugsjahr missing: Zuzug ohne Angabe zum Jahr d.h. kann Vertriebener oder Spaetaussiedler sein
* Annahme 1: wenn nach 1949 geboren, als Spaetaussiedler zugewandert
replace mig=21     if brdborn==8 & ausl==0 & eingeb==0 & gebj>1949 & jzuzug==9 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==0 & gebj>1949 & jzuzug==9 & mig==21
replace sa_erw=sa1 if brdborn==8 & ausl==0 & eingeb==0 & gebj>1949 & jzuzug==9 & mig==21
replace sa_erw=sa2 if brdborn==8 & ausl==0 & eingeb==0 & gebj>1949 & jzuzug==9 & mig==21 & sa2!=.
* Annahme 2: Wenn vor 1949 geboren und keine auslaendische SA dann Vertriebener 
replace mig=11     if brdborn==8 & ausl==0 & eingeb==0 & sadopp==0 & sa1==0 & jzuzug==9 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==0 & sadopp==0 & sa1==0 & jzuzug==9 & mig==11
replace sa_erw=sa1 if brdborn==8 & ausl==0 & eingeb==0 & sadopp==0 & sa1==0 & jzuzug==9 & mig==11
* Annahme 3: sonst Zuzug als Spaetaussiedler ohne Datumsangabe: 29 
replace mig=29     if brdborn==8 & ausl==0 & eingeb==0 & gebj<=1949 & sadopp==1 & sa1==0 & jzuzug==9 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==0 & gebj<=1949 & sadopp==1 & sa1==0 & jzuzug==9 & mig==29
replace sa_erw=sa1 if brdborn==8 & ausl==0 & eingeb==0 & gebj<=1949 & sadopp==1 & sa1==0 & jzuzug==9 & mig==29
replace sa_erw=sa2 if brdborn==8 & ausl==0 & eingeb==0 & gebj<=1949 & sadopp==1 & sa1==0 & jzuzug==9 & mig==29 & sa2!=.

* ... Jahrzuzug = 0
* Annahme 1
replace mig=21     if brdborn==8 & eingeb==0 & jzuzug==0 & gebj>1949 & mig==.
replace sa=sa1     if brdborn==8 & eingeb==0 & jzuzug==0 & gebj>1949 & mig==21
replace sa_erw=sa1 if brdborn==8 & eingeb==0 & jzuzug==0 & gebj>1949 & mig==21
replace sa_erw=sa2 if brdborn==8 & eingeb==0 & jzuzug==0 & gebj>1949 & mig==21 & sa2!=.
* Annahme 2
replace mig=11     if brdborn==8 & eingeb==0 & jzuzug==0 & gebj<=1949 & sadopp==0 & sa1==0 & mig==.
replace sa=sa1     if brdborn==8 & eingeb==0 & jzuzug==0 & gebj<=1949 & sadopp==0 & sa1==0 & mig==11
replace sa_erw=sa1 if brdborn==8 & eingeb==0 & jzuzug==0 & gebj<=1949 & sadopp==0 & sa1==0 & mig==11
* Annahme 3
replace mig=29     if brdborn==8 & eingeb==0 & jzuzug==0 & gebj<=1949 & sadopp==1 & sa1==0 & mig==.
replace sa=sa1     if brdborn==8 & eingeb==0 & jzuzug==0 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29
replace sa_erw=sa1 if brdborn==8 & eingeb==0 & jzuzug==0 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29
replace sa_erw=sa2 if brdborn==8 & eingeb==0 & jzuzug==0 & gebj<=1949 & sadopp==1 & sa1==0 & mig==29 & sa2!=.

* B) im Inland geboren: 
* B1) als Auslaender in D geboren 
replace mig=42     if brdborn==1 & ausl==1 & mig==.
replace sa=sa1     if brdborn==1 & ausl==1 & mig==42
replace sa_erw=sa1 if brdborn==1 & ausl==1 & mig==42

* B2) Eingebuergerter, in Deutschland geboren
replace mig=32     if brdborn==1 & ausl==0 & eingeb==1 & mig==.
replace sa=sa1     if brdborn==1 & ausl==0 & eingeb==1 & mig==32
replace sa_erw=sa3 if brdborn==1 & ausl==0 & eingeb==1 & mig==32
replace sa_erw=sa2 if brdborn==1 & ausl==0 & eingeb==1 & mig==32 & sa_erw==.
replace sa_erw=99  if brdborn==1 & ausl==0 & eingeb==1 & mig==32 & sa_erw==.

* B3) in Deutschland geborener Deutscher 
replace mig=77     if brdborn==1 & ausl==0 & eingeb==0 & mig==.
replace sa=sa1     if brdborn==1 & ausl==0 & eingeb==0 & mig==77
replace sa_erw=sa3 if brdborn==1 & ausl==0 & eingeb==0 & mig==77 & sa3!=.

* BRDBorn=9: keine Auskunft; kommt wohl nicht vor 
replace mig=99     if brdborn==9 & mig==.
replace sa=sa1     if brdborn==9 & mig==99
replace sa_erw=sa3 if brdborn==9 & mig==99 & sa3!=.

replace mig=0 if mig==.

* -------------------------------------------------------
* 2006 keine Plausibilisierung zum Spaetaussiedlerstatus 
* -------------------------------------------------------

rename mig mig2
format mig2 %2.0f
label var mig2 "Migrationsstatus nach Grundtypisierung"
/* label def mig2 ///
      11 "[11] Vertriebene vor 1950" ///
      21 "[21] Deutsche Zuwanderer o. (Spaet-)Aussiedler (ohne Einbuergerung)" ///
      29 "(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" ///
      31 "zugewanderte/r eingebuergerte/r Auslaender/in" ///
      32 "nicht zugewanderte/r eingebuergerte/r Auslaender/in" ///
      41 "zugewanderte/r Auslaender/in" ///
      42 "nicht zugewanderte/r Auslaender/in" ///
      77 "uneindeutig ob deutsch, vertrieben oder Spaetaussiedler", add modify
label val mig2 mig2 */

gen sa_erw2 = sa_erw
format sa_erw2 %2.0f
label var sa_erw2 "Erw. akt. Staatsangeh. zum Migrationsstatus nach Grundtypisierung [mig2]" 

* Zwischenspeicherung Grundtypisierung 
sort ef1 ef3 v4 v5
save temp_mig2.dta, replace


/* ============================================================================
2. Identifikation von 3-Generationen-Haushalten

Fuer die nachfolgende Typisierung des Migrationshintergrundes von Eltern unter 
Verwendung von Angaben der Grosseltern werden in diesem Schritt 3-Generationen-
Haushalte identifiziert und Identifikatoren fuer Eltern und Grosseltern 
gebildet. */


* VATER: EF54 Vater im Haushalt: fuer Ledige: 1=ja 8=nein 0=entf
*        EF55 Nr. des Vaters im Haushalt 

gen vnr = ef55 if (ef54==1)
label var vnr "Personennr. des Vaters (ef55)"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

preserve
keep if ef54==1
keep ef1 ef3 v4 vnr

* ==> Sortierung ... vnr
sort ef1 ef3 v4 vnr

rename vnr v5

gen v_kids=1
collapse (count) v_kids, by(ef1 ef3 v4 v5)
label var v_kids "Anzahl lediger Kinder eines Vaters"
save temp_V1.dta, replace
restore 

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 v5

* Anzahl der Kinder den Vaetern zuspielen 
merge m:m ef1 ef3 v4 v5 using temp_V1.dta
* order ef1 ef3 v4 v5 
* browse ef1 ef3 v4 v5 ef54 ef55 vnr v_kids, nolab 
* tab v_kids _merge, miss
* _merge=2: 131 Vaeter nicht gefunden, betreffen Jahresueberhang (ef5b=1)
keep if _merge!=2 // Ausschluss von Faellen fehlender Vaeter in den Daten
drop _merge

recode v_kids (1/99=1), gen(vater)
label var vater "Vater lediger Kinder im HH"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

preserve
keep if (vater==1)
keep  ef1 ef3 v4 v5 mig2 jzuzug ef366 ef372 
rename v5     vnr
rename mig2   mig_v
rename jzuzug jzuzug_v
rename ef366  ef366_v
rename ef372  ef372_v
sort ef1 ef3 v4 vnr
save temp_V1.dta, replace
restore

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 vnr
* Angaben des Vaters zuspielen 
merge m:m ef1 ef3 v4 vnr using temp_V1.dta
tab _merge ef54, miss
drop _merge
* tab mig_v vater, miss

* Sortierung des Ausgangsfiles wieder herstellen
sort ef1 ef3 v4 v5


* ---------------------------------------------------------------
* MUTTER: ef52 Mutter im Haushalt: fr Ledige: 1=ja 8=nein 0=entf
*         ef53 Nr. der Mutter im Haushalt 
gen mnr = ef53 if (ef52==1)
label var mnr "Personennr. der Mutter (ef53)"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

preserve
keep if ef52==1
keep ef1 ef3 v4 mnr

* ==> Sortierung ... mnr
sort ef1 ef3 v4 mnr
rename mnr v5
gen m_kids=1
collapse (count) m_kids, by(ef1 ef3 v4 v5)
label var m_kids "Anzahl lediger Kinder einer Mutter"
save temp_M1.dta, replace
restore

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 v5

* Anzahl der Kinder den Muettern zuspielen 
merge m:m ef1 ef3 v4 v5 using temp_M1.dta
* tab _merge ef52, miss
*  410 Muetter nicht gefunden
keep if _merge!=2 // Ausschluss von Faellen fehlender Muetter in den Daten
drop _merge

recode m_kids (1/99=1), gen(mutter)
label var mutter "Mutter lediger Kinder im HH"
* browse ef1 ef3 ef4 EF5 ef52 ef53 mnr m_kids mutter, nolab

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

preserve
keep if (mutter==1)
keep  ef1 ef3 v4 v5 mig2 jzuzug ef366 ef372 
rename v5      mnr
rename jzuzug  jzuzug_m
rename ef366   ef366_m
rename ef372   ef372_m
rename mig2    mig_m
sort ef1 ef3 v4 mnr
save temp_M1.dta, replace
restore


* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 v4 mnr
* Angaben der Mutter zuspielen 
merge m:m ef1 ef3 v4 mnr using temp_M1.dta
* tab _merge ef52, miss
drop _merge


* Eltern (Mutter oder Vater) mit Angaben zur (Gross-)Mutter:
*   Personennummer der Grossmutter
generate gmnr = ( (mutter==1 | vater==1) & ef52==1) * ef53

* Eltern (Mutter oder Vater) mit Angaben zum (Gross-)Vater: 
*   Personennummer des Grossvaters 
generate gvnr = ( (mutter==1 | vater==1) & ef54==1) * ef55

egen min_gmnr = min(gmnr * (gmnr>0)), by(ef1 ef3 v4)
egen max_gmnr = max(gmnr * (gmnr>0)), by(ef1 ef3 v4)
egen min_gvnr = min(gvnr * (gvnr>0)), by(ef1 ef3 v4)
egen max_gvnr = max(gvnr * (gvnr>0)), by(ef1 ef3 v4)

* Kontrolle: mehr als 1 Grossmutter(nummer) im HH?
tab max_gmnr min_gmnr if max_gmnr!=min_gmnr & (min_gmnr>0)

* Kontrolle: mehr als 1 Grossvater(nummer) im HH?
tab max_gvnr min_gvnr if max_gvnr!=min_gvnr & (min_gvnr>0)

* Grossvater-/mutter
gen gmutter = (max_gmnr==ef5a) if max_gmnr>0
gen gvater  = (max_gvnr==ef5a) if max_gvnr>0


/* ====================================================================
3. Endtypisierung der Grosseltern
   Im MZ 2006 nicht relevant, da keine Angaben zu den nicht im
   Haushalt lebenden Eltern vorhanden sind. Deshalb kann die 
   Grundtypisierung verwendet werden.
======================================================================= */


/* ====================================================================
4. Endtypisierung der Eltern

   Fuer jede Kombination von eigenem, vaeterlichen und muetterlichen 
   vorlaeufigen Migrationsstatus wird der resultierende endgueltige 
   Migrationsstatus zugewiesen. Diese Konversions-Prozedur wird nur 
   fuer im Inland Geborene angewandt.
   Abschliessend wird die Variable erweiterte Staatsangehoerigkeit 
   (SA_erw) ggf. durch Informationen zum Vater bzw. zur Mutter ergaenzt.                                                        .
======================================================================= */

* Ausgangssortierung
sort ef1 ef3 v4 v5

egen mig_gv    = max(mig2*(gvater==1)),   by(ef1 ef3 v4)
egen sa1_gv    = max(sa1*(gvater==1)),    by(ef1 ef3 v4)
egen sa2_gv    = max(sa2*(gvater==1)),    by(ef1 ef3 v4)
egen sa3_gv    = max(sa3*(gvater==1)),    by(ef1 ef3 v4)
egen sa_gv     = max(sa*(gvater==1)),     by(ef1 ef3 v4)
egen sa_erw_gv = max(sa_erw*(gvater==1)), by(ef1 ef3 v4)
* Angaben zum Status des Grossvaters nur falls der Grossvater 
*    der Vater ist, sonst SYSMIS
recode mig_gv sa1_gv sa2_gv sa3_gv sa_gv sa_erw_gv (nonmiss=.) if gvnr!=ef55

egen mig_gm    = max(mig2*(gmutter==1)),   by(ef1 ef3 v4)
egen sa1_gm    = max(sa1*(gmutter==1)),    by(ef1 ef3 v4)
egen sa2_gm    = max(sa2*(gmutter==1)),    by(ef1 ef3 v4)
egen sa3_gm    = max(sa3*(gmutter==1)),    by(ef1 ef3 v4)
egen sa_gm     = max(sa*(gmutter==1)),     by(ef1 ef3 v4)
egen sa_erw_gm = max(sa_erw*(gmutter==1)), by(ef1 ef3 v4)
* Angaben zum Status der Grossmutter nur falls die Grossmutter
*   die Mutter ist, sonst SYSMIS.
recode mig_gm sa1_gm sa2_gm sa3_gm sa_gm sa_erw_gm (nonmiss=.) if gmnr!=ef53

/* --------------------------------------------------------------------
Ab hier die eigentliche Endtypisierung des Migrationsstatus der Eltern 
mittels Konversions-Prozedur, bei der nur im Inland Geborene 
beruecksichtigt werden. */

recode mig2 (11 21 22 23 25 29 31 41=.) (*=1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle"

* EGRE: Eltern - Grosseltern .
gen egre = 1 if ( (vater==1  & (gvnr==ef55)) | /// Vater mit Grossvater 
                  (vater==1  & (gmnr==ef53)) | /// Vater mit Grossmutter
                  (mutter==1 & (gvnr==ef55)) | /// Mutter mit Grossvater
                  (mutter==1 & (gmnr==ef53)))  //  Mutter mit Grossmutter 
label var egre "Eltern mit Grosseltern im Haushalt"
format konvproc egre %1.0f

* Typisierung Eltern-Grosseltern
gen egretyp=0
replace egretyp = 1 if (vater==1  & gvnr==ef55)              // Vater mit Grossvater
replace egretyp = 2 if (vater==1  & gmnr==ef53)              // Vater mit Grossmutter
replace egretyp = 3 if (vater==1  & gvnr==ef55 & gmnr==ef53) // Vater mit Grossvater und -mutter
replace egretyp = 4 if (mutter==1 & gvnr==ef55)  // Mutter mit Grossvater
replace egretyp = 5 if (mutter==1 & gmnr==ef53)  // Mutter mit Grossmutter
replace egretyp = 6 if (mutter==1 & gvnr==ef55 & gmnr==ef53)  // Mutter mit Grossvater und -mutter
label var egretyp "Eltern mit Grosseltern im Haushalt"
label def egretyp 1 "[1] Vater mit Grossvater"   2 "[2] Vater mit Grossmutter" ///
                  3 "[3] Vater mit Grosseltern"  4 "[4] Mutter mit Grossvater" ///
                  5 "[5] Mutter mit Grossmutter" 6 "[6] Mutter mit Grosseltern" ///
                  0 "[0] TNZ"
format egretyp %1.0f

* Vorbereitung MATCH Konversionstabelle
* Nur im Inland geborene Eltern, die nicht Grosseltern sind (EGRETYP=1-6)
generate _mig_  = mig2   if (konvproc==1 & (vater==1 | mutter==1))    // MIG-Status Eltern vor Konversion
generate _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1) & egretyp==1)  // Vater mit Grossvater im HH
generate _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1) & egretyp==2)  // Vater mit Grossmutter
replace  _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1) & egretyp==3)  // Vater mit Grossvater und -mutter
replace  _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1) & egretyp==3)  // Vater mit Grossvater und -mutter
replace  _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1) & egretyp==4)  // Mutter mit Grossvater
replace  _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1) & egretyp==5)  // Mutter mit Grossmutter
replace  _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1) & egretyp==6)  // Mutter mit Grossvater und -mutter
replace  _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1) & egretyp==6)  // Mutter mit Grossvater und -mutter
replace  _migm_ = 99 if (konvproc==1 & (vater==1 | mutter==1) & _migm_==.)
replace  _migv_ = 99 if (konvproc==1 & (vater==1 | mutter==1) & _migv_==.)
format _mig_ _migv_ _migm_ %2.0f


/* conversion.dta --- ex conversion_2011.xls ---
 obs:         1,163
 vars:            6
variable name   variable label
---------------------------------------------------------
_mig_           Migrationsstatus Befragter VOR Konversion
_migv_          Migrationsstatus Vater
_migm_          Migrationsstatus Mutter
konvproc        Konstante (1) fuer Konversionsprozedur
migneu          Migrationsstatus Befragter konvertiert
kennung                           
*/



* ZWISCHENSPEICHERUNG GESAMTFILE
*    Ausgangssortierung
sort ef1 ef3 v4 v5
save temp.dta, replace

merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
* tab _merge, miss
drop _merge

* Ausgangssortierung
sort ef1 ef3 v4 v5

* Uebernahme konvertierter MIG-Typisierung
gen mig3 = mig2
replace mig3 = migneu if (egre==1 & konvproc==1 & migneu!=.)
format mig3 %2.0f

label var mig3 "Migrationsstatus nach Endtypisierung Eltern"
label def mig3 ///
    0 "[0] nicht zuordenbar (Rest)" ///
   11 "[11] Vertriebene vor 1950" ///
   21 "[21] Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)" ///
   22 "[22] Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)" ///
   25 "[25] (Spaet-)Aussiedler (mit Einbuergerung)" ///
   29 "[29] (Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" ///
   31 "[31] zugewanderte/r eingebuergerte/r Auslaender/in" ///
   32 "[32] nicht zugewanderte/r eingebuergerte/r Auslaender/in" ///
   41 "[41] zugewanderte/r Auslaender/in" ///
   42 "[42] nicht zugewanderte/r Auslaender/in" ///
   43 "[43] nicht zugewanderte/r Auslaender/in, beide Eltern hier geboren" ///
   52 "[52] Deutscher mit einseitigem Migrationshintergrund" ///
   53 "[53] Deutscher mit einseitigem Migrationshintergrund" ///
   54 "[54] Deutscher mit einseitigem Migrationshintergrund" ///
   62 "[62] Deutscher mit zweiseitigem Migrationshintergrund" ///
   63 "[63] Deutscher mit zweiseitigem Migrationshintergrund" ///
   64 "[64] Deutscher mit zweiseitigem Migrationshintergrund" ///
   77 "[77] uneindeutig ob deutsch, vertrieben oder Spaetaussiedler" ///
   99 "[99] fehlende/unvollstaendige Angaben"
label val mig3 mig3


* SA_erw durch aussagekraeftigen Vater- bzw. Muttereintrag ergaenzen, sofern 
*        noetig und moeglich
*        Nur im Inland geborene Eltern (ohne Grosseltern)
replace sa_erw = sa_erw_gv if (konvproc==1 & ((vater==1  & (gvater==0  | gvater==.) ) |   ///
                                              (mutter==1 & (gmutter==0 | gmutter==.)) ) & ///
		                      ( (sa_erw==0 | sa_erw==99) & (sa_erw_gv>0 & sa_erw_gv<99) ) )
replace sa_erw = sa_erw_gm if (konvproc==1 & ((vater==1  & (gvater==0  | gvater==.) ) |   ///
                                              (mutter==1 & (gmutter==0 | gmutter==.)) ) & ///
		                      ( (sa_erw==0 | sa_erw==99) & (sa_erw_gm>0 & sa_erw_gm<99) ) )

* Konversionsangaben loeschen
drop migneu _mig_ _migv_ _migm_ kennung konvproc

* Zwischenspeicherung Gesamtfile Grundtypisierung + Endtypisierung Eltern
*    Ausgangssortierung
sort ef1 ef3 v4 v5
save temp_mig3.dta, replace 



/* ====================================================================
5. Endtypisierung Befragte

Analog zur Endtypisierung der Eltern wird der endgueltige Migrationsstatus 
unter Beruecksichtigung der Kombinationen von eigenem, vaeterlichen und 
muetterlichen vorlaeufigen Migrationsstatus zugewiesen, wobei auch hier 
die Zuweisungen nur fuer die im Inland Geborenen zur Anwendung kommen und
die erweiterte Staatsangehoerigkeit (SA_erw) ggf. durch Angaben des Vaters
bzw. der Mutter ergaenzt wird.
Die Variable SA_erw ist Basis der Staatsangehoerigkeit zum Migrationsstatus
(MIGS). 
======================================================================= */

* Migrationsrelevante Eintraege fuer Vaeter: MIG3 SA1 SA2 SA3 SA SA_erw JZuzug

preserve
keep if vater==1
keep ef1 ef3 v4 v5 mig3 sa1 sa2 sa3 sa sa_erw jzuzug
rename v5      vnr 
rename mig3    mig_v
rename sa1     sa1_v
rename sa2     sa2_v
rename sa3     sa3_v
rename sa      sa_v
rename sa_erw  sa_erw_v
rename jzuzug  jzuzug_v

sort ef1 ef3 v4 vnr
save temp_V.dta, replace

restore

* GESAMTFILE 
use temp_mig3.dta, clear
sort ef1 ef3 v4 vnr
* Angaben des Vaters zuspielen 
merge m:m ef1 ef3 v4 vnr using temp_V.dta
* tab _merge ef54
drop _merge
* tab mig_v vater, miss

* Ausgangssortierung
sort ef1 ef3 v4 v5

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp_mig3.dta, replace

* ---------------------------------------------------------------- 
* Migrationsrelevante Eintraege fuer Muetter

preserve
keep if mutter==1
keep ef1 ef3 v4 v5 mig3 sa1 sa2 sa3 sa sa_erw jzuzug
rename v5      mnr 
rename mig3    mig_m
rename sa1     sa1_m
rename sa2     sa2_m
rename sa3     sa3_m
rename sa      sa_m
rename sa_erw  sa_erw_m
rename jzuzug  jzuzug_m
sort ef1 ef3 v4 mnr
save temp_M.dta, replace
restore

* GESAMTFILE 
use temp_mig3.dta, clear
sort ef1 ef3 v4 mnr

* Angaben der Mutter zuspielen 
merge m:m ef1 ef3 v4 mnr using temp_M.dta
* tab _merge ef52
drop _merge

* tab mig_m mutter, miss

* Zwischenspeicherung Gesamtfile
sort ef1 ef3 v4 v5
save temp.dta, replace

* ---------------------------------------------------------------- 
* Konversions-Prozedur nur fuer im Inland Geborene 
recode mig3 (11 21 22 23 25 29 31 41=.) (else=1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle"

/* =====================================================================
   Aufgrund inkonsistenter Identifikatoren (EF4, EF5a) bei Haushalte des 
   Jahresueberhangs liegen trotz Korrektur (s. o.) nicht fuer alle 
   Personen Angaben zu den Eltern vor, da nicht alle Eltern in den Daten
   enthalten sind, die gemaess den Ordnungsnummern (EF53, EF55) 
   vorhanden sein sollten. */   
gen vm_soll = 9 if (konvproc!=1)     // nicht im Inland Geborene
replace vm_soll = 4 if (konvproc==1) // im Inland Geborene ohne Angaben zu den Eltern
replace vm_soll = 1 if (konvproc==1 & (vnr==ef55) & (mnr==ef53)) // Vater und Mutter
replace vm_soll = 2 if (konvproc==1 & (vnr==ef55) & (mnr!=ef53)) // Vater 
replace vm_soll = 3 if (konvproc==1 & (vnr!=ef55) & (mnr==ef53)) //           Mutter 
* tab vm_soll if konvproc==1, miss
* tab mig_v vm_soll if konvproc==1, miss /* if (MIGVI^=. & MIGMI^=.) then do;  /* Gueltige Angaben fuer beide Eltern */
* list ef3 ef4 if konvproc==1 & mig_v==. & vm_soll<3, nol noobs // ==> Beispielhaushalt
* list ef3 ef4 v4 v5 ef5a ef12 ef52 ef53 ef54 ef55 ef44 ef46 mig3 mig_v mig_m vm_soll if ef3==3 & ef4==2, nol noobs sepby(ef3 ef4)
/*
  +--------------------------------------------------------------------------------------------------------------+
  | ef3   ef4   v4   v5   ef5a   ef12   ef52   ef53   ef54   ef55   ef44   ef46   mig3   mig_v   mig_m   vm_soll |
  |--------------------------------------------------------------------------------------------------------------|
  |   3     2    2    2      2      4      0     99      0     99     54      2     31       .       .         9 |
  |   3     2    2    3      3      1      1      2      1      1     21      1     31       .      31         9 |
  |   3     2    2    4      4      1      1      2      1      1     19      1     31       .      31         9 |
  |   3     2    2    5      5      1      1      2      1      1     18      1     31       .      31         9 |
  |   3     2    2    6      6      1      1      2      1      1     14      1     77       .      31         1 |
  +--------------------------------------------------------------------------------------------------------------+

* vm_soll=1: Es sollten Angaben zu beiden Eltern (EF53=2, EF55=1) vorliegen.
*            Es ist aber keine Person (Vater) mit EF5a=1 (EF55=1) im Haushalt vorhanden.
*/

gen vm_ist = 9 if (konvproc!=1)      // nicht im Inland Geborene
replace vm_ist = 4 if (konvproc==1) // im Inland Geborene ohne Angaben zu den Eltern     gueltige Mig-Angaben zu 
replace vm_ist = 1 if (konvproc==1 & (vnr==ef55 & mig_v!=.) & (mnr==ef53 & mig_m!=.)) // Vater und Mutter
replace vm_ist = 2 if (konvproc==1 & vm_ist>1 & (vnr==ef55 & mig_v!=.))               // Vater 
replace vm_ist = 3 if (konvproc==1 & vm_ist>2 & (mnr==ef53 & mig_m!=.))               //           Mutter 

label var vm_soll "Angaben zu den Eltern fuer im Inland Geborene - SOLL"
label var vm_ist  "Angaben zu den Eltern fuer im Inland Geborene - IST"
label def vm 9 "[9] nicht im Inland Geborene" ///
             1 "[1] beide Eltern" ///
             2 "[2] Vater" ///
             3 "[3] Mutter" ///
             4 "[4] keine Angaben"
label val vm_ist vm
label val vm_soll vm
* Fehlende Angaben zum Migrationsstatus des Vaters
* tab vm_ist vm_soll if vm_ist!=vm_soll & mig_v==., miss
* ... Migrationsstatus der Mutter
* tab vm_ist vm_soll if vm_ist!=vm_soll & mig_m==., miss

===================================================================== */ 

* Vorbereitung MATCH Konversionstabelle
generate _mig_  = mig3  if konvproc==1  // MIG-Status Person vor Konversion, im Inland geborene
generate _migv_ = 99 if konvproc==1     // MIG-Status Vater
generate _migm_ = 99 if konvproc==1     // MIG-Status Mutter
replace  _migv_ = mig_v if konvproc==1 & mig_v!=. // gueltige Angaben zum Vater
replace  _migm_ = mig_m if konvproc==1 & mig_m!=. // gueltige Angaben zur Mutter
recode   _migv_ _migm_ (22 23 = 21) if konvproc==1
format _mig_ _migv_ _migm_ %2.0f

* Konversionstabelle zuspielen 
sort _mig_ _migv_ _migm_ 
merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
drop _merge

* Ausgangssortierung
sort ef1 ef3 v4 v5

* neu, da durch Match ggf. ueberschrieben
drop konvproc
recode mig3 (11 21 22 23 25 29 31 41=.) (*=1), gen(konvproc)

* Migrationsstatus NACH Konversion zuweisen
generate mig4 = mig3
replace  mig4 = migneu if (konvproc==1 & migneu!=.)
label var mig4 "Migrationsstatus nach Endtypisierung Befragte"
format mig4 %2.0f


* 6. Umsetzung von Zeitreihenkompatibilitaet entfaellt im MZ 2006 


/* ===================================================================
7. Variablendefinitionen wie im SUF und fuer Fachserien-Ergebnisse */

* Recodierungen wie SUF
recode mig4 (0 77=0) (29 21=21), gen(mig) copyrest
label var mig "Migrationsstatus nach Endtypisierung Befragte"
format mig %2.0f
* SUF Value Labels 
recode mig (29=21)(77=0)
label def mig ///
  0 "[0] Deutsch ohne Mig-hintergrund(0); uneindeutig ob deutsch, vertrieben oder Spaetaussiedler(77)" ///
 11 "[11] Bis einschl. 1949 als Deutscher ohne Einbuergerung auf das heutige Bundesgebiet zugewandert" ///
 21 "[21] 21/29: 1950 und spaeter als Deutscher ohne Einbuergerung auf das heutige Bundesgebiet zugewandert(Spaetaussiedler)(21); (Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr(29)" /// 
 22 "[22] Ehegatte oder Kind von Spaetaussiedler, zeitgleich eingereist" /// 
 25 "[25] Spaetaussiedler mit formaler Einbuergerung" /// 
 31 "[31] Als Auslaender auf das heutige Bundesgebiet zugewandert und zwischenzeitlich eingebuergert" /// 
 32 "[32] Als Auslaender im heutigen Bundesgebiet geboren und zwischenzeitlich eingebuergert" /// 
 41 "[41] Als Auslaender auf das heutige Bundesgebiet zuwandert" /// 
 42 "[42] Als Auslaender im heutigen Bundesgebiet geboren, entweder beide Eltern als Auslnder zugewandert oder der eine Elternteil" /// 
 43 "[43] Als Auslaender im heutigen Bundesgebiet geboren, beide Eltern im heutigen Bundesgebiet geboren" /// 
 52 "[52] Deutscher mit einseitigem Mig-hintergrund; Mig-status durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 53 "[53] Deutscher mit einseitigem Mig-hintergrund; Mig-status durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 54 "[54] Deutscher mit einseitigem Mig-hintergrund; Mig-sstatus durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 62 "[62] Deutscher mit beidseitigem Mig-hintergrund; Mig-status durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 63 "[63] Deutscher mit beidseitigem Mig-hintergrund; Mig-status durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 64 "[64] Deutscher mit beidseitigem Mig-hintergrund; Mig-status durchweg identifizierbar, weil mit Eltern im Haushalt" /// 
 77 "[77] uneindeutig ob deutsch, vertrieben oder Spaetaussiedler" 
label val mig mig


* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag ergaenzen, 
*        sofern noetig und moeglich
replace sa_erw = sa_erw_v if (konvproc==1 & vnr==ef55 & (sa_erw==0 | sa_erw==99) & (sa_erw_v>0 & sa_erw_v<99))
replace sa_erw = sa_erw_m if (konvproc==1 & mnr==ef53 & (sa_erw==0 | sa_erw==99) & (sa_erw_m>0 & sa_erw_m<99))


/* ===================== MIGS ======================= 
Recodierung sa_erw => migs 

Keine einheitliche Recodierung aufgrund unterschiedlicher Vergroebung 
der Variablen zu Staatsangehoerigkeiten moeglich; s.o.
Auch nach Harmonisierung koennen Differenzen zu Ergebnissen der 
Fachserie damit zusammenhaengen, dass im SUF keine differenzierten
Angaben zur 2. Staatsangehoerigkeit vorliegen.
*/
generate migs = sa_erw
replace  migs = 0 if (mig==0)
format migs %2.0f
label var migs "Staatsangehoerigkeit: Migrationsstatus"
label def migs ///
    0 "Entfllt (Deutsche ohne weitere Staatsangehrigkeit)" /// 
    1 "EU-25: Belgien(01), Luxemburg(18), Irland(11), Zypern(37), Malta(19); Sonst. Europa: Estland(07), Lettland(15), Litauen(17), Slowenien(31)" /// 
    2 "Sonst. Europa: Bosnien und Herzegowina(02)" /// 
    3 "Sonst. Europa: Bulgarien(03), Rumnien(25)" /// 
    4 "EU-25: Dnemark(04), Finnland(08), Schweden(27)" /// 
    5 "Sonst. Europa: Ehemalige Sowjetunion(05)" /// 
    6 "Sonst. Europa: Ehemaliges Jugoslawien(06)" /// 
    9 "EU-25: Frankreich(09)" /// 
   10 "EU-25: Griechenland(10)" /// 
   12 "Sonst. Europa: Island(12), Liechtenstein(16), Norwegen(20), Schweiz(28), Sonstiges Europa(39)" /// 
   13 "EU-25: Italien(13)" /// 
   14 "Sonst. Europa: Kroatien(14)" /// 
   21 "EU-25: Niederlande(21)" /// 
   22 "EU-25: sterreich(22)" /// 
   23 "Sonst. Europa: Polen(23)" /// 
   24 "EU-25: Portugal(24), Spanien(32)" /// 
   26 "Sonst. Europa: Russische Fderation(26)" /// 
   29 "Sonst. Europa: Serbien und Montenegro(29)" /// 
   30 "Sonst. Europa: Slowakei(30), Tschechische Republik(33)" /// 
   34 "Sonst. Europa: Trkei(34)" /// 
   35 "Sonst. Europa: Ungarn(35)" /// 
   36 "EU-25: Vereinigtes Knigreich(36)" /// 
   38 "Sonst. Europa: Sonstiges Osteuropa(38)" /// 
   40 "Afrika: Marokko(40)" /// 
   41 "Afrika: Sonstiges Nordafrika(41)" /// 
   42 "Afrika: Sonstiges Afrika(42)" /// 
   43 "Amerika: Vereinigte Staaten(43), Sonstiges Nordamerika(43)" /// 
   45 "Amerika: Mittelamerika und Karibik(45), Sdamerika(46)" /// 
   47 "Naher und Mittlerer Osten: Irak(47)" /// 
   48 "Naher und Mittlerer Osten: Iran(48)" /// 
   49 "Sonstiger Naher und Mittlerer Osten(49)" /// 
   50 "Sd- und Sdostasien: Vietnam(50)" ///
   51 "Sd- und Sdostasien: Afghanistan(51)" ///
   52 "Sonstiges Sd- und Sdostasien(52), Sonstiges Ostasien(54)" ///
   53 "Ostasien: China(53)" ///
   55 "brige Welt(55), Staatenlos(98)" ///
   56 "Sonst. Europa: Ukraine(56)" ///
   57 "Naher und Mittlerer Osten: Kasachstan(57)" ///
   99 "Ohne Angabe"
numlabel migs, add mask("[#] ")

* ======= ENDE MIG-TYPISIERUNG =====

* Fallzahlen
tab1 mig migs, miss

* Hochgerechnete Verteilungen von MIG und MIGS
*    Bevoelkerung am Hauptwohnsitz, Hochrechnung: Jahresdurchschnitt
tab mig  if ef30>=1 & ef30<=2 [iw=ef952], miss
tab migs if ef30>=1 & ef30<=2 [iw=ef952], miss


/* ====================================================================
MIGRATIONSSTATUS
Vergleich mit Tabelle 2, Fachserie 1 Bevoelkerung und Erwerbstaetigkeit, 
Reihe 2.2, Bevoelkerung mit Migrationshintergrund 
Z_* := Zeilennummer in Tab. 2 
*/
recode mig (0/99=1) (else=.), gen(Z001) 
recode mig (0 11 77=1) (else=.), gen(Z002) 
recode mig (21 29 31 32 41 42 43 52 53 54 62 63 64=1) (else=.), gen(Z005)
recode mig (21 29 31 41=1) (else=.), gen(Z034)
recode mig (41=1) (else=.), gen(Z062)
recode mig (21 29 31=1) (else=.), gen(Z089)
recode mig (21 29=1) (else=.), gen(Z090)
recode mig (31=1) (else=.), gen(Z097)
recode mig (42 43 32 52 53 54 62 63 64=1) (else=.), gen(Z119)
recode mig (42 43=1) (else=.), gen(Z126)
recode mig (32 52 53 54 62 63 64=1) (else=.), gen(Z133)
recode mig (32=1) (else=.), gen(Z134)
recode mig (52 53 54 62 63 64=1) (else=.), gen(Z140)
recode mig (62 63 64=1) (else=.), gen(Z141)
recode mig (52 53 54=1) (else=.), gen(Z142)
format Z001-Z142 %1.0f
label var Z001  "Insgesamt [0-77]"
label var Z002  "Person ohne Migrationshintergrund [0,11,77]"
label var Z005  "Person mit Mig-hintergrund i.e.S. [21-64]"
label var Z034  "Bevoelkerung mit eigener Migrationserfahrung [21-31,41]"
label var Z062  "+ Auslaender mit Mig-erfahrung [41]"
label var Z089  "+ Deutsche mit Mig-erfahrung [21-31]"
label var Z090  "Deutsche mit Mig-erfahrung ohne Einbuergerung [21-29]"
label var Z097  "Deutsche mit Mig-erfahrung durch Einbuergerung [31]"
label var Z119  "Bevoelkerung ohne eigene Mig-erfahrung [32,42-64]"
label var Z126  "+ Auslaender ohne Mig-erfahrung[42-43]"
label var Z133  "+ Deutsche mit Mig-hintergrund ohne Mig-erfahrung [32,52-64]"
label var Z134  "  - durch Einbuergerung [32]"
label var Z140  "  - mit mind. 1 zugew. o. als Ausl. in D geb. Elternteil [52-64]"
label var Z141  "    # mit beidseitigem Mig-hintergrund [62-64]"
label var Z142  "    # mit einseitigem Mig-hintergrund [52-54]"

* Bevoelkerung am Hauptwohnsitz, Jahresdurchschnitt
summ Z001-Z142 if ef30>=1 & ef30<=2 [iw=ef952], sep(0)


/* ====================================================================
STAATSANGEHOERIGKEIT ZUM MIGRATIONSSTATUS
Vergleich mit Tabelle 2, Fachserie 1 Bevoelkerung und Erwerbstaetigkeit, 
Reihe 2.2, Bevoelkerung mit Migrationshintergrund 
Hinweis zur Auswertung von MIGS im Vergleich zur Veroeffentlichung mit 
Tab. 2, Fachserie 1, Reihe 2.2:
- Aufgrund unterschiedlicher Codierungen bei der Anonymisierung des 
  Scientific Use Files bei den Variablen EF369 und EF374 sowie im 
  Vergleich zu den Originaldaten kann die Staatsangehoerigkeit zum 
  Migrationsstatus (MIGS, SA_erw) nicht bzw. nur naeherungsweise 
  repliziert werden.  
- Deutsche Zuwanderer ohne Einbuergerung sowie in Deutschland geborene 
  Deutsche mit ein-/beidseitigem Migrationshintergund MIGS => 0 (deutsch)
*/
generate MIGS_R = migs
replace  MIGS_R = 0 if mig==0 | mig==11 | (mig>=21 & mig<=29) | (mig>=61 & mig<=64) | (mig>=71 & mig<=74)
* Z*: Lfd. Nr. in Tab. 2
* ohne vergroeberte Kategorien im SUF (z.B. Rumaenien/Bulgarien)
* Zu beachten: Abweichungen zur Fachserie bei Z25 o Sd- und Sdostasien, da inkl. Ostasien (54)
* Staatsangehrigkeiten zum Migrationsstatus fr Personen mit Mig-hintergrund i.e.S.
recode MIGS_R (0/99=1) (else=.), gen(Z05) 
recode MIGS_R (01/39 56 58 59=1) (else=.), gen(Z06)
recode MIGS_R (01 04 07/11 13 15 17/19 21/24 27 30/33 35/37=1) (else=.), gen(Z07)
recode MIGS_R (10=1) (else=.), gen(Z08)
recode MIGS_R (13=1) (else=.), gen(Z09)
recode MIGS_R (23=1) (else=.), gen(Z10)
recode MIGS_R (02 03 05 06 12 14 16 20 25 26 28 29 34 38 39 56 58 59=1) (else=.), gen(Z11)
recode MIGS_R (2=1) (else=.), gen(Z12)
recode MIGS_R (14=1) (else=.), gen(Z13)
recode MIGS_R (26=1) (else=.), gen(Z15)
recode MIGS_R (34=1) (else=.), gen(Z17)
recode MIGS_R (56=1) (else=.), gen(Z18)
recode MIGS_R (40/42=1) (else=.), gen(Z19)
recode MIGS_R (43/46=1) (else=.), gen(Z20)
recode MIGS_R (47/54 57=1) (else=.), gen(Z22)
recode MIGS_R (47/49 57=1) (else=.), gen(Z23)
recode MIGS_R (57=1) (else=.), gen(Z24)
* recode MIGS_R (50/52=1) (else=.), gen(Z25)
recode MIGS_R (98 99 0=1) (else=.), gen(Z26)
label var Z05 "Insgesamt"
label var Z06 "Europa"
label var Z07 "o EU 25"
label var Z08 "o Griechenland"
label var Z09 "o Italien"
label var Z10 "o Polen"
label var Z11 "o Sonstiges Europa"
label var Z12 "o Bosnien und Herzegowina"
label var Z13 "o Kroatien"
label var Z15 "o Russische Fderation"
label var Z17 "o Trkei"
label var Z18 "o Ukraine"
label var Z19 "Afrika"
label var Z20 "Amerika"
label var Z22 "Asien, Australien und Ozeanien"
label var Z23 "o Naher und Mittlerer Osten"
label var Z24 "Kasachstan"
* label var Z25 "o Sd- und Sdostasien [inkl. Ostasien (54)]"
label var Z26 "Ohne Angabe bzw. unzutreffend"

* Staatsangehrigkeiten zum Migrationsstatus fr Personen mit Mig-hintergrund i.e.S. (Z005)
* Bevoelkerung am Hauptwohnsitz, Jahresdurchschnitt
summ Z05-Z26 if ef30>=1 & ef30<=2 & Z005==1 [iw=ef952], sep(0)


* Arbeitsvariablen loeschen
drop  _mig_ _migv_ _migm_ migneu kennung konvproc


/* Sortierung nach revidierten Ordnungsnummern (EF1, EF3, EF4 (=EF4R), EF5a (=EF5aR), EF5b und EF12)
   oder Satznummer in Ausgangsdaten (ID_ORG) fuer Zusammenfuehren der erstellten Variablen 
   MIG, MIGS, MIGS_R zum Scientific Use File */
sort ID_ORG
 
* Zwischenspeicherung mit korrigierten IDs und ggf. Variablenauswahl
* keep ef1 ef3 ef4 ef5a ef5b ef12 ef30 ef952 ID_Org EF4_ORG  EF5a_ORG mig migs MIGS_R
save mig2006.dta

* ################################################################################
* PROGRAMMENDE
exit



